macro_rules! latency_histogram {
($name:expr, $help:expr) => { ... };
}Expand description
Convenience macro: register a histogram on the workspace registry with latency buckets suitable for tail-sensitive RPCs (50µs..2s).
macro_rules! latency_histogram {
($name:expr, $help:expr) => { ... };
}Convenience macro: register a histogram on the workspace registry with latency buckets suitable for tail-sensitive RPCs (50µs..2s).